@@ -13,16 +13,21 @@ Topic :: Software Development :: Libraries :: Python Modules
 keywords = """
 scientific computing
 parallel computing
+PETSc
+"""
+platforms = """
+Linux
+Unix
 """
 
-metadata = {             
+metadata = {
     'author'           : 'Lisandro Dalcin',
-    'author_email'     : 'dalcinl@users.sourceforge.net',
-    'url'              : 'http://code.google.com/p/petsc4py/',
+    'author_email'     : 'dalcinl@gmail.com',
     'classifiers'      : [c for c in classifiers.split('\n') if c],
     'keywords'         : [k for k in keywords.split('\n')    if k],
+    'platforms'        : [p for p in platforms.split('\n')   if p],
     'license'          : 'Public Domain',
     'platforms'        : ['POSIX'],
     'maintainer'       : 'Lisandro Dalcin',
-    'maintainer_email' : 'dalcinl@users.sourceforge.net',
+    'maintainer_email' : 'dalcinl@gmail.com',
     }
