@@ -48,13 +48,12 @@ class CommType(type):
         if reg_func is not None:
             reg_func(mcs)
             delattr(_petsc, reg_name)
-        # type registration
-        if not hasattr(_petsc, '_' + name):
-            setattr(_petsc, '_' + name, mcs)
 
 # --------------------------------------------------------------------
 
-class Comm(_petsc.Comm):
+CommBase = getattr(_petsc, 'Comm')
+
+class Comm(CommBase):
 
     """
     MPI Communicator.
@@ -124,7 +123,6 @@ class Comm(_petsc.Comm):
         """
         return _petsc.PetscGlobalSum(local, self)
 
-        
     size = property(getSize)
     rank = property(getRank)
 
