@@ -43,12 +43,17 @@ Complex = _petsc.PetscComplex
 
 # --------------------------------------------------------------------
 
-DECIDE    = _petsc.PETSC_DECIDE
-DEFAULT   = _petsc.PETSC_DEFAULT
+DECIDE = _petsc.PETSC_DECIDE
+"""Standard way of passing in integer or floating point parameter
+where you wish PETSc to use the default."""
+
+DEFAULT = _petsc.PETSC_DEFAULT
+"""Standard way of passing in integer or floating point parameter
+where you wish PETSc to use the default."""
+
 DETERMINE = _petsc.PETSC_DETERMINE
-"""PETSc constants for default arguments. Standard way of passing in
-integer or floating point parameter where you wish PETSc to use the
-default."""
+"""Standard way of passing in integer or floating point parameter
+where you wish PETSc to compute the required value."""
 
 # --------------------------------------------------------------------
 
@@ -56,12 +61,16 @@ class Truth:
     """
     Truth values.
 
-    .. note:: These constants are rarely needed, you can use the
-              standard ``True`` and ``False`` bool instances available
-              in Python.
+    - `TRUE`: true value.
+    - `FALSE`: false value.
+    - `YES`: alias for `TRUE`.
+    - `NO`: alias for `FALSE`.
+
+    .. note:: These constants are actually integers and rarely needed,
+       you can use the ``True`` and ``False`` boolean instances.
     """
-    FALSE = _petsc.PETSC_FALSE
     TRUE  = _petsc.PETSC_TRUE
+    FALSE = _petsc.PETSC_FALSE
     YES   = _petsc.PETSC_YES
     NO    = _petsc.PETSC_NO
 
@@ -72,10 +81,8 @@ class InsertMode:
 
     - `INSERT_VALUES`: Puts a value into a vector or matrix,
       overwrites any previous value.
-
     - `ADD_VALUES`: Adds a value into a vector or matrix, if there
       previously was no value, just puts the value into that location.
-
     - `MAX_VALUES`: Puts the maximum of the scattered/gathered values
       and the current value into each location.
     """
@@ -97,7 +104,6 @@ class ScatterMode:
 
     - `FORWARD`: Scatters the values as dictated by the call to
       `Scatter.create()`.
-
     - `REVERSE`: Moves the values in the opposite direction than the
       ones indicated in the call to `Scatter.create()`.
     """
@@ -114,21 +120,17 @@ class NormType:
     Norm types for vectors and matrices.
 
     - `NORM_1`: the one norm
-      + ||v|| = sum_i | v_i | for vectors.
+      + ||v|| = sum_i abs(v_i) for vectors.
       + ||A|| = max_j || v_*j|| for matrices (maximum column sum).
-
     - `NORM_2`: the two norm
       + ||v|| = sqrt(sum_i (v_i)^2) for vectors.
       + not supported for matrices.
-                
     - `NORM_FROBENIUS`: the Frobenius norm
       + same as `NORM_2` for vectors.
       + ||A|| = sqrt(sum_ij (A_ij)^2) for matrices.
-
     - `NORM_INFINITY`: the infinity norm
-      + ||v|| = max_i |v_i| for vectors.
+      + ||v|| = max_i abs(v_i) for vectors.
       + ||A|| = max_i || v_i* || for matrices (maximum row sum).
-
     - `NORM_MAX`: same as `NORM_INFINITY`.
     """
     # native
@@ -149,6 +151,4 @@ class NormType:
     FRB = FROBENIUS
     INF = INFINITY
     
-
 # --------------------------------------------------------------------
-
