@@ -60,7 +60,7 @@ class KSP(Object):
     Abstract PETSc object that manages all Krylov methods.
     """
     
-    class Type(object):
+    class Type:
         """
         KSP types.
         """
@@ -69,6 +69,7 @@ class KSP(Object):
         CG         = _petsc.KSPCG
         CGNE       = _petsc.KSPCGNE
         STCG       = _petsc.KSPSTCG
+        GLTR       = _petsc.KSPGLTR
         GMRES      = _petsc.KSPGMRES
         FGMRES     = _petsc.KSPFGMRES
         LGMRES     = _petsc.KSPLGMRES
@@ -86,25 +87,6 @@ class KSP(Object):
         SYMMLQ     = _petsc.KSPSYMMLQ
         LCD        = _petsc.KSPLCD
 
-        def __init__(self, ksp_type):
-            self._ksp_type = ksp_type
-        def __call__(self, name, bases, dct):
-            klass = type(KSP)(name, bases, dct)
-            setattr(klass, 'TYPE', self._ksp_type)
-            def __init__(self, ksp=None, *targs, **kwargs):
-                """See `KSP.create()` and KSP.setType()."""
-                super(KSP, self).__init__(*targs, **kwargs)
-                ksp_type = getattr(type(self), 'TYPE', None)
-                if isinstance(ksp, KSP):
-                    _petsc.KSP_init(self, ksp, ksp_type)
-                else:
-                    comm = ksp
-                    _petsc.KSPCreate(comm, self)
-                    if ksp_type is not None:
-                        _petsc.KSPSetType(self, ksp_type)
-            setattr(klass, '__init__', __init__)
-            return klass
-
     class NormType:
         """
         Norm that is passed in the Krylov convergence test routines.
@@ -124,17 +106,25 @@ class KSP(Object):
         """
         Reason a Krylov method was said to have converged or diverged.
 
-        + CONVERGED_ITERATING - this only occurs if
-         `KSP.getConvergedReason()` is called during `KSP.solve()`
-         
+        + `CONVERGED_ITERATING`: this only occurs if
+          `KSP.getConvergedReason()` is called during `KSP.solve()`
+
+        + `CONVERGED_RTOL`:
+        + `CONVERGED_ATOL`:
+        + `CONVERGED_ITS`:
+
+        + `DIVERGED_ITS`:
+        + `DIVERGED_BREAKDOWN`:
+        + `DIVERGED_DTOL`:
+    
         """
         # converged
-        CONVERGED_RTOL             = _petsc.KSP_CONVERGED_RTOL
-        CONVERGED_ATOL             = _petsc.KSP_CONVERGED_ATOL
-        CONVERGED_ITS              = _petsc.KSP_CONVERGED_ITS
-        CONVERGED_STCG_NEG_CURVE   = _petsc.KSP_CONVERGED_STCG_NEG_CURVE
-        CONVERGED_STCG_CONSTRAINED = _petsc.KSP_CONVERGED_STCG_CONSTRAINED
-        CONVERGED_STEP_LENGTH      = _petsc.KSP_CONVERGED_STEP_LENGTH
+        CONVERGED_RTOL           = _petsc.KSP_CONVERGED_RTOL
+        CONVERGED_ATOL           = _petsc.KSP_CONVERGED_ATOL
+        CONVERGED_ITS            = _petsc.KSP_CONVERGED_ITS
+        CONVERGED_CG_NEG_CURVE   = _petsc.KSP_CONVERGED_CG_NEG_CURVE
+        CONVERGED_CG_CONSTRAINED = _petsc.KSP_CONVERGED_CG_CONSTRAINED
+        CONVERGED_STEP_LENGTH    = _petsc.KSP_CONVERGED_STEP_LENGTH
         #iterating
         CONVERGED_ITERATING       = _petsc.KSP_CONVERGED_ITERATING
         ITERATING                 = _petsc.KSP_CONVERGED_ITERATING
@@ -568,26 +558,45 @@ class KSP(Object):
 
 # --------------------------------------------------------------------
 
+
+class KSPType(object):
+    
+    def __init__(self, ksp_type):
+        self._type = ksp_type
+    def __call__(self, name, bases, dct):
+        klass = type(KSP)(name, bases, dct)
+        setattr(klass, 'TYPE', self._type)
+        if '__init__' in dct: return klass
+        def __init__(self, ksp=None, *targs, **kwargs):
+            """See `KSP.create()` and `KSP.setType()`."""
+            super(KSP, self).__init__(*targs, **kwargs)
+            _type = getattr(type(self), 'TYPE')
+            if isinstance(ksp, KSP):
+                _petsc.KSP_init(self, ksp, _type)
+            else: # asume arg is a comm
+                _petsc.KSPCreate(ksp, self)
+                _petsc.KSPSetType(self, _type)
+        setattr(klass, '__init__', __init__)
+        return klass
+
 class KSPPREONLY(KSP):
     """
     Implements a stub method that applies ONLY the preconditioner.
     """
-    __metaclass__ = KSP.Type(KSP.Type.PREONLY)
-
+    __metaclass__ = KSPType(KSP.Type.PREONLY)
 
 class KSPCG(KSP):
     """
     Implements the Conjugate Gradients method.
     """
-    __metaclass__ = KSP.Type(KSP.Type.CG)
-
+    __metaclass__ = KSPType(KSP.Type.CG)
 
 class KSPGMRES(KSP):
     """
     Implements the Generalized Minimal Residual method.
     """
-    __metaclass__ = KSP.Type(KSP.Type.GMRES)
-            
+    __metaclass__ = KSPType(KSP.Type.GMRES)
+
 
 # --------------------------------------------------------------------
 
@@ -598,7 +607,7 @@ class PC(Object):
     Abstract PETSc object that manages all preconditioners.
     """
 
-    class Type(object):
+    class Type:
         """
         PC types.
         """
@@ -628,28 +637,9 @@ class PC(Object):
         ML         = _petsc.PCML
         PROMETHEUS = _petsc.PCPROMETHEUS
         GALERKIN   = _petsc.PCGALERKIN
-
+        
         SCHUR      = _petsc.PCSCHUR
 
-        def __init__(self, pc_type):
-            self._pc_type = pc_type
-        def __call__(self, name, bases, dct):
-            klass = type(PC)(name, bases, dct)
-            setattr(klass, 'TYPE', self._pc_type)
-            def __init__(self, pc=None, *targs, **kwargs):
-                """See `PC.create()` and PC.setType()."""
-                super(PC, self).__init__(*targs, **kwargs)
-                pc_type = getattr(type(self), 'TYPE', None)
-                if isinstance(pc, PC):
-                    _petsc.PC_init(self, pc, pc_type)
-                else:
-                    comm = pc
-                    _petsc.PCCreate(comm, self)
-                    if pc_type is not None:
-                        _petsc.PCSetType(self, pc_type)
-            setattr(klass, '__init__', __init__)
-            return klass
-
     class Side:
         """
         PC sides
@@ -804,45 +794,65 @@ class PC(Object):
 # --------------------------------------------------------------------
 
 
+class PCType(object):
+    
+    def __init__(self, pc_type):
+        self._type = pc_type
+    def __call__(self, name, bases, dct):
+        klass = type(PC)(name, bases, dct)
+        setattr(klass, 'TYPE', self._type)
+        if '__init__' in dct: return klass
+        def __init__(self, pc=None, *targs, **kwargs):
+            """See `PC.create()` and `PC.setType()`."""
+            super(PC, self).__init__(*targs, **kwargs)
+            _type = getattr(type(self), 'TYPE')
+            if isinstance(pc, PC):
+                _petsc.PC_init(self, pc, _type)
+            else: # asume arg is a comm
+                _petsc.PCCreate(pc, self)
+                _petsc.PCSetType(self, _type)
+        setattr(klass, '__init__', __init__)
+        return klass
+
 class PCNone(PC):
     """
     This is used when you wish to employ a nonpreconditioned Krylov
     method.
     """
-    __metaclass__ = PC.Type(PC.Type.NONE)
+    __metaclass__ = PCType(PC.Type.NONE)
 
 class PCLU(PC):
     """
     Use a direct solver, based on LU factorization, as a
     preconditioner.
     """
-    __metaclass__ = PC.Type(PC.Type.LU)
+    __metaclass__ = PCType(PC.Type.LU)
 
 class PCILU(PC):
     """
     Incomplete LU factorization preconditioner.
     """
-    __metaclass__ = PC.Type(PC.Type.ILU)
+    __metaclass__ = PCType(PC.Type.ILU)
 
 class PCCHOLESKY(PC):
     """
     Use a direct solver, based on Cholesky factorization, as a
     preconditioner.
     """
-    __metaclass__ = PC.Type(PC.Type.CHOLESKY)
+    __metaclass__ = PCType(PC.Type.CHOLESKY)
 
 class PCICC(PC):
     """
     Incomplete Cholesky factorization preconditioner.
     """
-    __metaclass__ = PC.Type(PC.Type.ICC)
+    __metaclass__ = PCType(PC.Type.ICC)
 
 class PCShell(PC):
     """
     A PC type to be used to define your own preconditioning
     operator.
     """
-    __metaclass__ = PC.Type(PC.Type.SHELL)
+    __metaclass__ = PCType(PC.Type.SHELL)
 
     def getContext(self):
         """
