@@ -7,6 +7,7 @@
 Logging Facilities
 ==================
 
+Access to logging facilities.
 """
 
 # --------------------------------------------------------------------
@@ -33,15 +34,17 @@ class Log(object):
     """
     PETSc Logging.
     """
-    
+
     @staticmethod
-    def begin(all=False):
+    def begin():
         """
         """
-        if all:
-            _petsc.PetscLogAllBegin()
-        else:
-            _petsc.PetscLogBegin()
+        _petsc.PetscLogBegin()
+
+    def beginAll():
+        """
+        """
+        _petsc.PetscLogAllBegin()
 
     @staticmethod
     def logActions(flag):
@@ -59,8 +62,6 @@ class Log(object):
     def printSummary(filename='stdout', comm=None):
         """
         """
-        if filename is None:
-            return
         _petsc.PetscLogPrintSummary(comm, filename)
 
     # Stages
@@ -72,12 +73,24 @@ class Log(object):
         """
         return _petsc.PetscLogStageRegister(name)
 
+    @staticmethod
+    def stageGetVisible(stage):
+        """
+        """
+        return bool(_petsc.PetscLogStageGetVisible(stage))
+
     @staticmethod
     def stageSetVisible(stage, flag):
         """
         """
         _petsc.PetscLogStageSetVisible(stage, flag)
 
+    @staticmethod
+    def stageGetActive(stage):
+        """
+        """
+        return bool(_petsc.PetscLogStageGetActive(stage))
+
     @staticmethod
     def stageSetActive(stage, flag):
         """
@@ -208,3 +221,81 @@ class Log(object):
         return _petsc.PetscGetCPUTime()
 
 # --------------------------------------------------------------------
+
+class Stage(int):
+
+    """
+    """
+
+    def __new__(cls, stage):
+        if isinstance(stage, str):
+            _stage = Log.stageRegister(stage)
+        else:
+            _stage = int(stage)
+        return int.__new__(cls, _stage)
+
+    def push(self):
+        """
+        """
+        Log.stagePush(self)
+
+    def pop(self):
+        """
+        """
+        Log.stagePop()
+
+    active  = property(fget=Log.stageGetActive,
+                       fset=Log.stageSetActive)
+
+    visible = property(fget=Log.stageGetVisible,
+                       fset=Log.stageSetVisible)
+
+
+class Class(int):
+
+    """
+    """
+
+    def __new__(cls, cookie):
+        if isinstance(cookie, str):
+            _cookie = Log.classRegister(cookie)
+        else:
+            _cookie = int(cookie)
+        return int.__new__(cls, _cookie)
+
+    active  = property(fget=None,
+                       fset=Log.classSetActive)
+
+
+class Event(int):
+
+    """
+    """
+
+    def __new__(cls, event, cookie=None):
+        if isinstance(event, str):
+            _event = Log.eventRegister(event, cookie)
+        else:
+            _event = int(event)
+        return int.__new__(cls, _event)
+
+    def begin(self, *objs):
+        """
+        """
+        Log.eventBegin(self, *objs)
+
+    def end(self, *objs):
+        """
+        """
+        Log.eventEnd(self, *objs)
+
+    active  = property(fget=None,
+                       fset=Log.eventSetActive)
+
+# --------------------------------------------------------------------
+
+Log.Stage = Stage
+Log.Class = Class
+Log.Event = Event
+
+# --------------------------------------------------------------------
