@@ -13,16 +13,16 @@ __date__     = '$Date$'
 __version__  = '$Version$'
 __revision__ = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
 from petsc4py.Error     import *
 from petsc4py.Constants import *
-from petsc4py.Options   import *
-from petsc4py.Sys       import *
-from petsc4py.Log       import *
 from petsc4py.Comm      import *
+from petsc4py.Sys       import *
+from petsc4py.Options   import *
+from petsc4py.Log       import *
 from petsc4py.Object    import *
 from petsc4py.Viewer    import *
 from petsc4py.Random    import *
