@@ -51,7 +51,7 @@ class SNES(Object):
     Abstract PETSc object that manages all nonlinear solves.
     """
 
-    class Type(object):
+    class Type:
         """
         SNES types.
 
@@ -66,25 +66,6 @@ class SNES(Object):
         # aliases
         LINE_SEARCH  = LS
         TRUST_REGION = TR
-        # metaclass
-        def __init__(self, snes_type):
-            self._snes_type = snes_type
-        def __call__(self, name, bases, dct):
-            klass = type(SNES)(name, bases, dct)
-            setattr(klass, 'TYPE', self._snes_type)
-            def __init__(self, snes=None, *targs, **kwargs):
-                """See `SNES.create()` and SNES.setType()."""
-                super(SNES, self).__init__(*targs, **kwargs)
-                snes_type = getattr(type(self), 'TYPE', None)
-                if isinstance(snes, SNES):
-                    _petsc.SNES_init(self, snes, snes_type)
-                else:
-                    comm = snes
-                    _petsc.SNESCreate(comm, self)
-                    if snes_type is not None:
-                        _petsc.SNESSetType(self, snes_type)
-            setattr(klass, '__init__', __init__)
-            return klass
 
     class ConvergedReason:
         """
@@ -365,7 +346,17 @@ class SNES(Object):
         values = _petsc.SNESGetParametersEW(self)
         return dict(zip(names, values))
         
+    def getUseMF(self):
+        """
+        Determine whether SNES is using matrix-free jacobians
+        """
+        return bool(_petsc.SNESGetUseMFFD(self))
 
+    def setUseMF(self, flag):
+        """
+        Set SNES to use matrix-free jacobians
+        """
+        _petsc.SNESSetUseMFFD(self, flag)
         
     def setMonitor(self, monitor):
         """
@@ -482,11 +473,31 @@ class SNES(Object):
 
 # --------------------------------------------------------------------
 
+
+class SNESType(object):
+    def __init__(self, snes_type):
+        self._type = snes_type
+    def __call__(self, name, bases, dct):
+        klass = type(SNES)(name, bases, dct)
+        setattr(klass, 'TYPE', self._type)
+        if '__init__' in dct: return klass
+        def __init__(self, snes=None, *targs, **kwargs):
+            """See `SNES.create()` and SNES.setType()."""
+            super(SNES, self).__init__(*targs, **kwargs)
+            _type = getattr(type(self), 'TYPE')
+            if isinstance(snes, SNES):
+                _petsc.SNES_init(self, snes, _type)
+            else: # assume arg is a comm
+                _petsc.SNESCreate(snes, self)
+                _petsc.SNESSetType(self, _type)
+        setattr(klass, '__init__', __init__)
+        return klass
+
 class SNESLS(SNES):
     """
     Newton based nonlinear solver that uses a line search
     """
-    __metaclass__ = SNES.Type(SNES.Type.LS)
+    __metaclass__ = SNESType(SNES.Type.LS)
 
     class LSType:
         """
@@ -515,7 +526,7 @@ class SNESLS(SNES):
         :Parameters:
           - `alpha`: the scalar such that
             ``.5*f_{n+1} . f_{n+1} <= .5*f_n . f_n - alpha |f_n . J . f_n|``.
-          - `maxstep`: the maximum norm of the update vector.
+          - `maxsteps`: the maximum norm of the update vector.
           - `steptol`: the minimum norm fraction of the original step
             after scaling.
         """
@@ -549,7 +560,7 @@ class SNESTR(SNES):
     """
     Newton based nonlinear solver that uses a trust region.
     """
-    __metaclass__ = SNES.Type(SNES.Type.TR)
+    __metaclass__ = SNESType(SNES.Type.TR)
 
     def setParamsTR(self, tol=None):
         """
