@@ -4,8 +4,8 @@
 # Id: $Id$
 
 """
-Time-steppers - ODE integrators - TS
-====================================
+Time-Steppers and ODE integrators (TS)
+======================================
 
 The time-stepping components provide ODE integrators and
 pseudo-timestepping. `TS` internally employs KSP/SNES to solve the
@@ -18,7 +18,7 @@ __date__     = '$Date$'
 __version__  = '$Version$'
 __revision__ = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
@@ -49,7 +49,7 @@ class TS(Object):
 
     class Type(object):
         """
-        TS types
+        TS types.
         """
         # native
         EULER           = _petsc.TS_EULER
@@ -85,7 +85,7 @@ class TS(Object):
 
     def create(self, comm=None):
         """
-        Creates an empty timestepper. The problem type can be set with
+        Create an empty timestepper. The problem type can be set with
         `setProblemType()` and the type of solver can then be set with
         `setType()`.
         """
@@ -93,32 +93,32 @@ class TS(Object):
 
     def getProblemType(self):
         """
-        Gets the type of problem to be solved.
+        Get the type of problem to be solved.
         """
         return _petsc.TSGetProblemType(self)
 
     def setProblemType(self, problem_type):
         """
-        Sets the type of problem to be solved.
+        Set the type of problem to be solved.
         """
         problem_type = _petsc.get_attr(TS.ProblemType, problem_type)
         _petsc.TSSetProblemType(self, problem_type)
 
     def getApplicationContext(self):
         """
-        Gets the user-defined context for the timestepper.
+        Get the user-defined context for the timestepper.
         """
         return _petsc.TSGetApplicationContext(self)
 
     def setApplicationContext(self, context):
         """
-        Sets an optional user-defined context for the timestepper.
+        Set an optional user-defined context for the timestepper.
         """
         _petsc.TSSetApplicationContext(self, context)
 
     def getKSP(self):
         """
-        Returns the KSP (linear solver) associated with a TS
+        Return the KSP (linear solver) associated with a TS
         (timestepper) object.
 
         .. note::
@@ -131,23 +131,9 @@ class TS(Object):
         """
         return _petsc.TSGetKSP(self)
 
-    def setRHSMatrix(self, function, A, P=None):
-        """
-        Sets the function to compute the matrix A, where U_t = A(t) U.
-        Also sets the location to store the matrix.
-        """
-        _petsc.TSSetRHSMatrix(self, A, P, function)
-
-    def setLHSMatrix(self, function, A, P=None):
-        """
-        Sets the function to compute the matrix A, where A U_t = F(U).
-        Also sets the location to store the matrix.
-        """
-        _petsc.TSSetLHSMatrix(self, A, P, function)
-
     def getSNES(self):
         """
-        Returns the SNES (nonlinear solver) associated with a
+        Return the SNES (nonlinear solver) associated with a
         TS (timestepper) object.
 
         .. note::
@@ -160,48 +146,50 @@ class TS(Object):
         """
         return _petsc.TSGetSNES(self)
 
-    def setRHSFunction(self, function):
+    def setRHSFunction(self, function, f=None):
         """
-        Sets the routine for evaluating the function,
-        F(t,u), where U_t = F(t,u).
+        Set the routine (and perhaps a function vector) for
+        evaluating the function, F(t,u), where U_t = F(t,u).
 
         .. note::
            The calling convention for `function` is::
+
              function(TS ts, float time, Vec u, Vec F ) -> None
         """
-        _petsc.TSSetRHSFunction(self, function)
+        _petsc.TSSetRHSFunction(self, f, function)
 
-    def computeRHSFunction(self, time, x, y):
+    def computeRHSFunction(self, t, x, y):
         """
-        Evaluates the right-hand-side function.
+        Evaluate the right-hand-side function.
         """
-        _petsc.TSComputeRHSFunction(self, time, x, y)
+        _petsc.TSComputeRHSFunction(self, t, x, y)
 
     setFunction     = setRHSFunction
     computeFunction = computeRHSFunction
 
     def getRHSJacobian(self):
         """
-        Returns the Jacobian matrix at the present timestep.
+        Return the Jacobian matrix at the present timestep.
         """
         return tuple(_petsc.TSGetRHSJacobian(self))
 
     def setRHSJacobian(self, jacobian, J, P=None):
         """
-        Sets the function to compute the Jacobian of F, where U_t =
+        Set the function to compute the Jacobian of F, where U_t =
         F(U,t), as well as the location to store the Jacobian matrix.
 
         .. note::
            The calling convention for `jacobian` is::
+
              jacobian(TS ts, float time, Vec u, Mat J, Mat P) -> None
         """
         _petsc.TSSetRHSJacobian(self, J, P, jacobian)
 
-    def computeRHSJacobian(self, time, x, J, P):
+    def computeRHSJacobian(self, t, x, J, P):
         """
-        Evaluates the right-hand-side Jacobian.
+        Evaluate the right-hand-side Jacobian.
         """
-        _petsc.TSComputeRHSJacobian(self, time, x, J, P)
+        _petsc.TSComputeRHSJacobian(self, t, x, J, P)
 
     getJacobian     = getRHSJacobian
     setJacobian     = setRHSJacobian
@@ -209,37 +197,37 @@ class TS(Object):
 
     def getTime(self):
         """
-        Gets the current time.
+        Get the current time.
         """
         return _petsc.TSGetTime(self)
 
     def setTime(self, time):
         """
-        Sets the current time to be used.
+        Set the current time to be used.
         """
         _petsc.TSSetTime(self, time)
 
     def getTimeStep(self):
         """
-        Gets the current timestep size.
+        Get the current timestep size.
         """
         return _petsc.TSGetTimeStep(self)
 
     def setTimeStep(self, time_step):
         """
-        Allows the user to reset the timestep at any time,
+        Allow to reset the timestep at any time,
         """
         _petsc.TSSetTimeStep(self, time_step)
 
     def setInitialTimeStep(self, initial_time, initial_time_step):
         """
-        Sets the initial timestep to be used, as well as the initial time.
+        Set the initial timestep to be used, as well as the initial time.
         """
         _petsc.TSSetInitialTimeStep(self, initial_time, initial_time_step)
     
     def getStepNumber(self):
         """
-        Gets the current timestep number.
+        Get the current timestep number.
         """
         return _petsc.TSGetTimeStepNumber(self)
 
@@ -247,35 +235,35 @@ class TS(Object):
 
     def getMaxTime(self):
         """
-        Gets the maximum time to use for iteration.
+        Get the maximum time to use for iteration.
         """
         _, max_time = _petsc.TSGetDuration(self)
         return max_time
 
     def setMaxTime(self, max_time):
         """
-        Sets the maximum time to use for iteration.
+        Set the maximum time to use for iteration.
         """
         max_steps, _ = _petsc.TSGetDuration(self)
         _petsc.TSSetDuration(self, max_steps, max_time)
 
     def getMaxSteps(self):
         """
-        Gets the maximum number of timesteps to use for iteration.
+        Get the maximum number of timesteps to use for iteration.
         """
         max_steps, _ = _petsc.TSGetDuration(self)
         return max_steps
 
     def setMaxSteps(self, max_steps):
         """
-        Sets the maximum number of timesteps to use for iteration.
+        Set the maximum number of timesteps to use for iteration.
         """
         _, max_time = _petsc.TSGetDuration(self)
         _petsc.TSSetDuration(self, max_steps, max_time)
         
     def getDuration(self):
         """
-        Gets the maximum time and maximum number of timesteps to use
+        Get the maximum time and maximum number of timesteps to use
         for iteration.
         """
         max_steps, max_time = _petsc.TSGetDuration(self)
@@ -283,7 +271,7 @@ class TS(Object):
 
     def setDuration(self, max_time, max_steps=None):
         """
-        Sets the maximum time and optionally the maximum number of
+        Set the maximum time and optionally the maximum number of
         timesteps to use for iteration.
         """
         _max_steps, _max_time = _petsc.TSGetDuration(self)
@@ -295,7 +283,7 @@ class TS(Object):
 
     def getSolution(self):
         """
-        Returns the solution at the present timestep. It is valid to
+        Return the solution at the present timestep. It is valid to
         call this routine inside the function that you are evaluating
         in order to move to the new timestep. This vector does not
         change until the solution at the next timestep has been
@@ -305,17 +293,18 @@ class TS(Object):
 
     def setSolution(self, u):
         """
-        Sets the initial solution vector.
+        Set the initial solution vector.
         """
         _petsc.TSSetSolution(self, u)
 
     def setMonitor(self, monitor):
         """
-        Sets an additional function that is to be used at every
+        Set an additional function that is to be used at every
         timestep to display the iteration's progress.
 
         .. note::
            The calling convention for `monitor` is::
+
              monitor(TS ts, int step, float time, Vec u) -> None
         
         .. note::
@@ -325,7 +314,7 @@ class TS(Object):
 
     def cancelMonitor(self):
         """
-        Clears all the monitors that have been set on a timestepper.
+        Clear all the monitors that have been set on a timestepper.
 
         .. note::
            There is no way to remove a single, specific monitor.
@@ -341,6 +330,7 @@ class TS(Object):
 
         .. note::
            The calling convention for `prestep` is::
+
              prestep(TS ts) -> None
         """
         _petsc.TSSetPreStep(self, prestep)
@@ -349,10 +339,11 @@ class TS(Object):
         """
         Sets the general-purpose update function called at the
         beginning of every time step. This function can change the
-        time step returning a float value.
+        time step if it returns a float value.
 
         .. note::
            The calling convention for `update` is::
+
              update(TS ts, float time, float time_step) -> None | time_step
         """
         _petsc.TSSetUpdate(self, update)
@@ -364,6 +355,7 @@ class TS(Object):
 
         .. note::
            The calling convention for `poststep` is::
+
              poststep(TS ts) -> None
         """
         _petsc.TSSetPostStep(self, poststep)
@@ -372,7 +364,7 @@ class TS(Object):
         """
         Steps the requested number of timesteps.
 
-        :Return:
+        :Returns:
           - number of iterations until termination.
           - time until termination.
         """
