@@ -50,7 +50,7 @@ class Vec(Object):
     Abstract PETSc vector object.
     """
 
-    class Type(object):
+    class Type:
         """
         Vec types.
         """
@@ -59,26 +59,13 @@ class Vec(Object):
         FETI   = _petsc.VECFETI
         SHARED = _petsc.VECSHARED
         SIEVE  = _petsc.VECSIEVE
-        def __init__(self, vec_type):
-            self._vec_type = vec_type
-        def __call__(self, name, bases, dct):
-            klass = type(Vec)(name, bases, dct)
-            setattr(klass, 'TYPE', self._vec_type)
-            if '__init__' not in dct:
-                def __init__(self, vec=None, *targs, **kwargs):
-                    """See `Vec.create()` and Vec.setType()."""
-                    super(Vec, self).__init__(*targs, **kwargs)
-                    vec_type = getattr(type(self), 'TYPE', None)
-                    _petsc.Vec_init(self, vec, vec_type)
-                setattr(klass, '__init__', __init__)
-            return klass
 
     class Option:
         """
         Vector options
         """
         IGNORE_OFF_PROC_ENTRIES = _petsc.VEC_IGNORE_OFF_PROC_ENTRIES
-        TREAT_OFF_PROC_ENTRIES  = _petsc.VEC_TREAT_OFF_PROC_ENTRIES
+        IGNORE_NEGATIVE_INDICES = _petsc.VEC_IGNORE_NEGATIVE_INDICES
 
     def __init__(self, *targs, **kwargs):
         super(Vec, self).__init__(*targs, **kwargs)
@@ -145,13 +132,14 @@ class Vec(Object):
         `setType()` (or perhaps `setFromOptions()`).
 
         :Parameters:
-           - `comm`: MPI communicator to use (defaults to `COMM_WORLD`).
+          - `comm`: MPI communicator to use (defaults to `COMM_WORLD`).
 
        :Returns:
          - the created vector.
 
-        .. note:: If you never call `setSizes()` and `setType()` it
-           will generate an error when you try to use the vector.
+        .. note:: If you never call `Vec.setSizes()` and
+           `Vec.setType()` it will generate an error when you try to
+           use the vector.
         """
         return _petsc.VecCreate(comm, self)
 
@@ -162,10 +150,10 @@ class Vec(Object):
         :Parameters:
            - `size`:  vector length.
            - `bsize`: vector block size (optional).
-           - `comm`: MPI communicator to use (defaults to `COMM_SELF`,
-             must be uniprocessor).
+           - `comm`: MPI communicator to use
+             (defaults to `COMM_SELF`, must be uniprocessor).
 
-       :Returns:
+        :Returns:
          - the created sequential vector.
         """
         comm, n = _petsc.vecseq_size(comm, size, bsize)
@@ -205,8 +193,8 @@ class Vec(Object):
           - `bsize`: vector block size (optional).
           - `comm`:  MPI communicator (defaults to `COMM_WORLD`).
 
-       .. note:: Currently `VecShared` is available only on the SGI.
-          Otherwise, this `Vec` is the same as `VecMPI`.
+        .. note:: Currently `VecShared` is available only on the SGI.
+           Otherwise, this `Vec` is the same as `VecMPI`.
 
         :Returns:
           - the created shared vector.
@@ -225,7 +213,7 @@ class Vec(Object):
           - `size`: sequence ``(n, N)`` with local and global vector
             length (any can be `DECIDE` to have calculated if other is
             given) or integer indicating global size.
-          - `ghost`: ghost nodes.
+          - `ghosts`: indices of ghost nodes.
           - `bsize`: vector block size (optional).
           - `comm`:  MPI communicator (defaults to `COMM_WORLD`).
 
@@ -295,8 +283,8 @@ class Vec(Object):
 
     def setSizes(self, sizes, bsize=None):
         """
-        Sets the local and global sizes of a vector,
-        and optionally the block size.
+        Sets the local and global sizes of a vector, and optionally
+        the block size.
         """
         comm = _petsc.PetscObjectGetComm(self)
         if _petsc.PetscCommGetSize(comm) == 1:
@@ -311,20 +299,20 @@ class Vec(Object):
     def getBlockSize(self):
         """
         Gets the blocksize for the vector, i.e. what is used for
-        `setValuesBlocked()` and `setValuesBlockedLocal()`.
+        `Vec.setValuesBlocked()` and `Vec.setValuesBlockedLocal()`.
 
-        .. note:: All vectors obtained by `duplicate()` inherit the
-           same block size.
+        .. note:: All vectors obtained by `Vec.duplicate()` inherit
+           the same block size.
         """
         return _petsc.VecGetBlockSize(self)
 
     def setBlockSize(self, bsize):
         """
-        Sets the blocksize for future calls to `setValuesBlocked()`
-        and `setValuesBlockedLocal()`.
+        Sets the blocksize for future calls to
+        `Vec.setValuesBlocked()` and `Vec.setValuesBlockedLocal()`.
 
-        .. note:: All vectors obtained by `duplicate()` inherit the
-           same block size.
+        .. note:: All vectors obtained by `Vec.duplicate()` inherit
+           the same block size.
         """
         bsize = _petsc.obj_bsize(bsize)
         _petsc.VecSetBlockSize(self, bsize)
@@ -344,8 +332,8 @@ class Vec(Object):
         Creates and returns qa new vector of the same type structure
         (parallel layout) as an existing vector.
 
-        .. tip:: Use `duplicate()` to form additional vectors of the
-           same type and parallel layout as an existing vector.
+        .. tip:: Use `Vec.duplicate()` to form additional vectors of
+           the same type and parallel layout as an existing vector.
         """
         return _petsc.VecDuplicate(self)
 
@@ -358,8 +346,8 @@ class Vec(Object):
 
         :Returns:
            - `vec` if `vec` is provided. Otherwise, a new vector is
-             created with `duplicate()`, values are copied to it, and
-             that vector is returned.
+             created with `Vec.duplicate()`, values are copied to it,
+             and that vector is returned.
         
         .. note:: For default parallel PETSc vectors, both `self` and
            `vec` must be distributed in the same manner; local copies
@@ -374,7 +362,7 @@ class Vec(Object):
     def Load(viewer, vec_type=None):
         """
         Load and return a vector that has been stored in binary format
-        with `view()`.
+        with `Vec.view()`.
         """
         vec_type = _petsc.get_attr(Vec.Type, vec_type)
         return _petsc.VecLoad(viewer, vec_type)
@@ -382,23 +370,18 @@ class Vec(Object):
     def load(self, viewer):
         """
         Load a vector that has been stored in binary format with
-        `view()`.
+        `Vec.view()`.
         """
         _petsc.VecLoadIntoVector(viewer, self)
 
     loadIntoVector = load
 
-    def setOption(self, option):
+    def setOption(self, option, flag):
         """
         Set an option for controling a vector's behavior.
         """
-        try:
-            options = iter(option)
-        except TypeError:
-            options = (option,)
-        for option in options:
-            opt = _petsc.get_attr(Vec.Option, option)
-            _petsc.VecSetOption(self, opt)
+        opt = _petsc.get_attr(Vec.Option, option)
+        _petsc.VecSetOption(self, opt, flag)
 
     def equal(self, vec):
         """
@@ -451,11 +434,13 @@ class Vec(Object):
     
     def normBegin(self, norm_type=None):
         """
+        Start a split phase norm computation.
         """
         _petsc.VecNormBegin(self, norm_type)
 
     def normEnd(self, norm_type=None):
         """
+        End a split phase norm computation.
         """
         return _petsc.VecNormEnd(self, norm_type)
     
@@ -500,7 +485,7 @@ class Vec(Object):
         _petsc.VecConjugate(self)
         
     def setRandom(self, random=None):
-        """self[i] <- random()"""
+        """self[i] <- random value"""
         _petsc.VecSetRandom(self, random)
 
     def zeroEntries(self):
@@ -605,14 +590,14 @@ class Vec(Object):
           - `array` - the array.
 
         ..notes:: You can return to the original vector array with a
-          call to `resetArray()`.
+          call to `Vec.resetArray()`.
         """
         _petsc.VecPlaceArray(self, array)
 
     def resetArray(self):
         """
         Reset a vector to use its default memory. Call this after the
-        use of `placeArray()`.
+        use of `Vec.placeArray()`.
         """
         _petsc.VecResetArray(self)
 
@@ -646,16 +631,17 @@ class Vec(Object):
         :Parameters:
           - `indices`: array of indices.
           - `values`: array of values.
-          - `insert_mode`: either `INSERT_VALUES` to replaces existing
-            entries with new values, or `ADD_VALUES` to add values to
-            any existing entries.
+          - `insert_mode`: either `InsertMode.INSERT_VALUES` to
+            replaces existing entries with new values, or
+            `InsertMode.ADD_VALUES` to add values to any existing
+            entries.
         """
         _petsc.VecSetValues(self, indices, values, insert_mode)
         
     def setLGMapping(self, lgmap):
         """
         Set a local numbering to global numbering used by
-        `setValuesLocal()` to allow users to insert vector entries
+        `Vec.setValuesLocal()` to allow users to insert vector entries
         using a local (per-processor) numbering.
         """
         _petsc.VecSetLocalToGlobalMapping(self, lgmap)
@@ -690,20 +676,20 @@ class Vec(Object):
     def assemblyBegin(self):
         """
         Begin assembling the vector.  This routine should be called
-        after completing all calls to `setValues()`.
+        after completing all calls to `Vec.setValues()`.
         """
         _petsc.VecAssemblyBegin(self)
 
     def assemblyEnd(self):
         """
         Complete assembling the vector.  This routine should be called
-        after `assemblyBegin()`.
+        after `Vec.assemblyBegin()`.
         """
         _petsc.VecAssemblyEnd(self)
 
     def assemble(self):
         """
-        Call `assemblyBegin()` and `assemblyEnd()`.
+        Call `Vec.assemblyBegin()` and `Vec.assemblyEnd()`.
         """
         _petsc.VecAssemblyBegin(self)
         _petsc.VecAssemblyEnd(self)
@@ -777,8 +763,6 @@ class Vec(Object):
         _petsc.VecGhostUpdateBegin(self, insert_mode, scatter_mode)
         _petsc.VecGhostUpdateEnd(self, insert_mode, scatter_mode)
 
-    option = property(fset=setOption,
-                      doc='Set an option or sequence of options')
     array = property(getArray, setArray)
     sizes = property(getSizes, setSizes)
     
@@ -794,12 +778,29 @@ class Vec(Object):
 
 # --------------------------------------------------------------------
 
+
+class VecType(object):
+    def __init__(self, vec_type):
+        self._type = vec_type
+    def __call__(self, name, bases, dct):
+        klass = type(Vec)(name, bases, dct)
+        setattr(klass, 'TYPE', self._type)
+        if '__init__' in dct: return klass
+        def __init__(self, vec=None, *targs, **kwargs):
+            """See `Vec.create()` and `Vec.setType()`."""
+            super(Vec, self).__init__(*targs, **kwargs)
+            _type = getattr(type(self), 'TYPE')
+            _petsc.Vec_init(self, vec, _type)
+        setattr(klass, '__init__', __init__)
+        return klass
+
 class VecSeq(Vec):
     """
     Sequential vector implementation.
     """
-    __metaclass__ = Vec.Type(Vec.Type.SEQ)
+    __metaclass__ = VecType(Vec.Type.SEQ)
     def __init__(self, *targs, **kwargs):
+        """See `Vec.createSeq()`."""
         super(VecSeq, self).__init__(*targs, **kwargs)
         self.createSeq(*targs, **kwargs)
         
@@ -807,8 +808,9 @@ class VecMPI(Vec):
     """
     Parallel vector implementation.
     """
-    __metaclass__ = Vec.Type(Vec.Type.MPI)
+    __metaclass__ = VecType(Vec.Type.MPI)
     def __init__(self, *targs, **kwargs):
+        """See `Vec.createMPI()`."""
         super(VecMPI, self).__init__(*targs, **kwargs)
         self.createMPI(*targs, **kwargs)
 
@@ -816,8 +818,9 @@ class VecShared(Vec):
     """
     Parallel vector implementation that uses shared memory.
     """
-    __metaclass__ = Vec.Type(Vec.Type.SHARED)
+    __metaclass__ = VecType(Vec.Type.SHARED)
     def __init__(self, *targs, **kwargs):
+        """See `Vec.createShared()`."""
         super(VecShared, self).__init__(*targs, **kwargs)
         self.createShared(*targs, **kwargs)
 
@@ -825,12 +828,14 @@ class VecSieve(Vec):
     """
     The parallel vector implementation based upon Sieve fields.
     """
-    __metaclass__ = Vec.Type(Vec.Type.SIEVE)
+    __metaclass__ = VecType(Vec.Type.SIEVE)
     def __init__(self, *targs, **kwargs):
+        """See `Vec.createSieve()`."""
         super(VecSieve, self).__init__(*targs, **kwargs)
         #self.createSieve(*targs, **kwargs)
         raise NotImplementedError
 
+
 # --------------------------------------------------------------------
 
 
@@ -852,36 +857,36 @@ class Scatter(Object):
 
     .. note:: 
 
-       In calls to `Scatter.[begin|end]()` you can use different
-       vectors than the `vec_from` and `vec_to` you used to create the
-       scatter context; BUT they must have the same parallel data
-       layout, for example, they could be obtained from
+       In calls to `Scatter.begin()` and `Scatter.end()` you can use
+       different vectors than the 'vec_from' and vec_to' you used to
+       create the scatter context; BUT they must have the same
+       parallel data layout, for example, they could be obtained from
        `Vec.duplicate()`.
 
        A scatter context **CANNOT** be used in two or more
        simultaneous scatters; that is you cannot call a second
-       `begin()` with the same scatter context until a matching
-       `end()` has been called. In this case a separate scatter
-       context is needed for each concurrent scatter, for example it
-       could be obtained with `copy()`.
+       `Scatter.begin()` with the same scatter context until a
+       matching `Scatter.end()` has been called. In this case a
+       separate scatter context is needed for each concurrent scatter,
+       for example it could be obtained with `Scatter.copy()`.
 
        You cannot change the values in the input vector between the
-       calls to `begin()` and `end()`.
+       calls to `Scatter.begin()` and `Scatter.end()`.
 
        If you use `ScatterMode.REVERSE` the first two arguments for
-       `begin()` and `end()` should be reversed, from the
-       `ScatterMode.FORWARD`.
+       `Scatter.begin()` and `Scatter.end()` should be reversed, from
+       the `ScatterMode.FORWARD`.
     """
 
     def __init__(self, *targs, **kwargs):
-        """See `create()`"""
+        """See `Scatter.create()`"""
         super(Scatter, self).__init__(*targs, **kwargs)
         if targs or kwargs:
             self.create(*targs, **kwargs)
         
         
     def __call__(self, vec_from, vec_to, insert_mode, scatter_mode):
-        """Same as `scatter()`"""
+        """Same as `Scatter.scatter()`"""
         self.scatter(vec_from, vec_to, insert_mode, scatter_mode)
 
     def create(self, vec_from, is_from, vec_to, is_to):
@@ -962,7 +967,8 @@ class Scatter(Object):
     def begin(self, vec_from, vec_to, insert_mode, scatter_mode):
         """
         Begins a generalized scatter from one vector to
-        another. Complete the scattering phase with `scatterEnd()`.
+        another. Complete the scattering phase with
+        `Scatter.end()`.
         """
         _petsc.VecScatterBegin(self, vec_from, vec_to,
                                insert_mode, scatter_mode)
@@ -970,7 +976,7 @@ class Scatter(Object):
     def end(self, vec_from, vec_to, insert_mode, scatter_mode):
         """
         Ends a generalized scatter from one vector to another.
-        Call after first calling `scatterBegin()`.
+        Call after first calling `Scatter.begin()`.
         """
         _petsc.VecScatterEnd(self, vec_from, vec_to,
                              insert_mode, scatter_mode)
