@@ -143,13 +143,14 @@ class Viewer(Object):
         if name is None or mode is None:
             viewer = _petsc.PetscViewerBinaryCreate(comm, self)
             if mode is not None:
-                mode = _petsc.get_attr(ViewerFile.FileMode, mode)
+                fmodes = ViewerFile.FileMode
+                mode = _petsc.get_attr(fmodes, mode)
                 _petsc.PetscViewerFileSetMode(viewer, mode)
             if name is not None:
                 _petsc.PetscViewerFileSetName(viewer, name)
         else:
-            fmode = ViewerFile.FileMode
-            mode = _petsc.get_attr(fmode, mode, fmode.WRITE)
+            fmodes = ViewerFile.FileMode
+            mode = _petsc.get_attr(fmodes, mode, fmodes.WRITE)
             viewer = _petsc.PetscViewerBinaryOpen(comm, name,
                                                   mode, self)
         if format is not None:
@@ -184,7 +185,7 @@ class Viewer(Object):
             w = h = _petsc.PETSC_DECIDE
         else:
             size = _petsc.get_attr(ViewerDraw.WinSize, size)
-            if type(size) is int:
+            if isinstance(size, int):
                 w = h = size
             else:
                 w, h = size
