@@ -72,10 +72,10 @@ class TestKSPBase(object):
         b.set(10)
         x.setRandom()
         self.ksp.setOperators(A)
-        self.ksp.logResidualHistory()
+        self.ksp.setResidualHistory()
         self.ksp.solve(b, x)
         rh = self.ksp.getResidualHistory()
-        self.ksp.logResidualHistory(0)
+        self.ksp.setResidualHistory(0)
         rh = self.ksp.getResidualHistory()
         self.assertEqual(len(rh), 0)
         del A, x, b
