@@ -20,11 +20,15 @@ class TestLib(unittest.TestCase):
         for f in files:
             fd = open(f)
             for line in fd:
-                if '_petsc.' in line:
-                    bit = line.split('_petsc.')[1]
-                    m = regex.match(bit)
-                    sym = m.group()
-                    symbols.add(sym)
+                if line.lstrip().startswith('#'):
+                    continue
+                if '_petsc.' not in line:
+                    continue
+                bit = line.split('_petsc.')[1]
+                m = regex.match(bit)
+                sym = m.group()
+                symbols.add(sym)
+            fd.close()
         from petsc4py.lib import _petsc
         undef = []
         for sym in symbols:
