@@ -23,6 +23,9 @@ class Function:
 
 class Jacobian:
     def __call__(self, snes, x, J, P):
+        if J.getType() == PETSc.Mat.Type.MFFD:
+            J.assemble()
+            J = P
         J[0,0] = 2.0*x[0] + x[1]; J[0,1] = x[0];
         J[1,0] = x[1];            J[1,1] = x[0] + 2.0*x[1];
         J.assemble()
@@ -89,7 +92,7 @@ class TestSNESBase(object):
         func = Function()
         self.snes.setFunction(func, r)
         x, y = r.duplicate(), r.duplicate()
-        x[0:2] = [1, 2]
+        x[0], x[1] = [1, 2]
         self.snes.computeFunction(x, y)
         self.assertAlmostEqual(abs(y[0]), 0.0)
         self.assertAlmostEqual(abs(y[1]), 0.0)
@@ -117,7 +120,7 @@ class TestSNESBase(object):
         jac = Jacobian()
         self.snes.setJacobian(jac, J)
         x = PETSc.Vec().createSeq(2)
-        x[0:2] = [1, 2]
+        x[0], x[1] = [1, 2]
         self.snes.computeJacobian(x, J)
 
     def testGetSetSol(self):
@@ -230,6 +233,35 @@ class TestSNESBase(object):
         self.snes.setParamsEW(**params)
         params = self.snes.getParamsEW()
         self.assertEqual(params['version'], 1)
+
+    def testMF(self):
+        #self.snes.setOptionsPrefix('MF-')
+        #opts = PETSc.Options(self.snes)
+        #opts['mat_mffd_type'] = 'ds'
+        #opts['snes_monitor']  = 'stdout'
+        #opts['ksp_monitor']   = 'stdout'
+        #opts['snes_view']     = 'stdout'
+        r = PETSc.Vec().createSeq(2)
+        J = PETSc.Mat().createSeqAIJ(2)
+        x = PETSc.Vec().createSeq(2)
+        self.snes.setSolution(x)
+        b = PETSc.Vec().createSeq(2)
+        self.snes.setRhs(b)
+        fun = Function()
+        jac = Jacobian()
+        self.snes.setFunction(fun, r)
+        self.snes.setJacobian(jac, J)
+        self.assertFalse(self.snes.getUseMF())
+        self.snes.setUseMF(False)
+        self.assertFalse(self.snes.getUseMF())
+        self.snes.setUseMF(True)
+        self.assertTrue(self.snes.getUseMF())
+        self.snes.setFromOptions()
+        x.setArray([2,3])
+        b.set(0)
+        self.snes.solve()
+        self.assertAlmostEqual(abs(x[0]), 1.0)
+        self.assertAlmostEqual(abs(x[1]), 2.0)
         
 # --------------------------------------------------------------------
 
