@@ -16,10 +16,10 @@ class TestSubTypes(unittest.TestCase):
     def testTS(self):
         self._testCls(PETSc.TS)
         
-    def _testCls(self, klass):
+    def _testCls(self, klass, *t, **k):
         for cls in klass.__subclasses__():
             try:
-                obj1 = cls()
+                obj1 = cls(*t,**k)
             except PETSc.Error, e:
                 if 'Unknown type' in e[1]:
                     return
@@ -33,6 +33,14 @@ class TestSubTypes(unittest.TestCase):
             obj1 = cls(PETSc.COMM_SELF)
             self.assertEqual(obj1.type, cls.TYPE)
             
+    def testVec(self):
+        self._testVecOrMat(PETSc.Vec)
+    def testMat(self):
+        self._testVecOrMat(PETSc.Mat)
+    def _testVecOrMat(self, klass, *t, **k):
+        for cls in klass.__subclasses__():
+            mat_type = cls.__name__[3:].lower()
+            self.assertTrue(cls.TYPE == mat_type)
 
 # --------------------------------------------------------------------
 
